@@ -51,24 +51,23 @@ ev_job_run_mode_get_type (void)
 }
 
 GType
-ev_render_flags_get_type (void)
+ev_job_page_data_flags_get_type (void)
 {
   static volatile gsize g_define_type_id__volatile = 0;
  
   if (g_once_init_enter (&g_define_type_id__volatile)) {
     static const GFlagsValue values[] = {
-      { EV_RENDER_INCLUDE_NONE, "EV_RENDER_INCLUDE_NONE", "none" },
-      { EV_RENDER_INCLUDE_LINKS, "EV_RENDER_INCLUDE_LINKS", "links" },
-      { EV_RENDER_INCLUDE_TEXT, "EV_RENDER_INCLUDE_TEXT", "text" },
-      { EV_RENDER_INCLUDE_SELECTION, "EV_RENDER_INCLUDE_SELECTION", "selection" },
-      { EV_RENDER_INCLUDE_IMAGES, "EV_RENDER_INCLUDE_IMAGES", "images" },
-      { EV_RENDER_INCLUDE_FORMS, "EV_RENDER_INCLUDE_FORMS", "forms" },
-      { EV_RENDER_INCLUDE_ANNOTS, "EV_RENDER_INCLUDE_ANNOTS", "annots" },
-      { EV_RENDER_INCLUDE_ALL, "EV_RENDER_INCLUDE_ALL", "all" },
+      { EV_PAGE_DATA_INCLUDE_NONE, "EV_PAGE_DATA_INCLUDE_NONE", "none" },
+      { EV_PAGE_DATA_INCLUDE_LINKS, "EV_PAGE_DATA_INCLUDE_LINKS", "links" },
+      { EV_PAGE_DATA_INCLUDE_TEXT, "EV_PAGE_DATA_INCLUDE_TEXT", "text" },
+      { EV_PAGE_DATA_INCLUDE_IMAGES, "EV_PAGE_DATA_INCLUDE_IMAGES", "images" },
+      { EV_PAGE_DATA_INCLUDE_FORMS, "EV_PAGE_DATA_INCLUDE_FORMS", "forms" },
+      { EV_PAGE_DATA_INCLUDE_ANNOTS, "EV_PAGE_DATA_INCLUDE_ANNOTS", "annots" },
+      { EV_PAGE_DATA_INCLUDE_ALL, "EV_PAGE_DATA_INCLUDE_ALL", "all" },
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_flags_register_static (g_intern_static_string ("EvRenderFlags"), values);
+       g_flags_register_static (g_intern_static_string ("EvJobPageDataFlags"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
